#
# spec file for package perl-Sereal-Encoder
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Sereal-Encoder
Name:           perl-Sereal-Encoder
Version:        5.004
Release:        1.6
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Binary serialization module for Perl (encoder part)
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/Y/YV/YVES/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 7.0
BuildRequires:  perl(ExtUtils::ParseXS) >= 2.21
BuildRequires:  perl(Sereal::Decoder) >= 5.004
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::Differences)
BuildRequires:  perl(Test::LongString)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warn)
Requires:       perl(Sereal::Decoder) >= 5.004
%{perl_requires}

%description
This library implements an efficient, compact-output, and feature-rich
serializer using a binary protocol called _Sereal_. Its sister module
Sereal::Decoder implements a decoder for this format. The two are released
separately to allow for independent and safer upgrading. If you care
greatly about performance, consider reading the Sereal::Performance
documentation after finishing this document.

The Sereal protocol version emitted by this encoder implementation is
currently protocol version 4 by default.

The protocol specification and many other bits of documentation can be
found in the github repository. Right now, the specification is at
https://github.com/Sereal/Sereal/blob/master/sereal_spec.pod, there is a
discussion of the design objectives in
https://github.com/Sereal/Sereal/blob/master/README.pod, and the output of
our benchmarks can be seen at
https://github.com/Sereal/Sereal/wiki/Sereal-Comparison-Graphs. For more
information on getting the best performance out of Sereal, have a look at
the "PERFORMANCE" section below.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
# Don't build with smp_flags!
make

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes

%changelog
* Thu Apr 20 2023 Tina Müller <timueller+perl@suse.de>
- updated to 5.004
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  5.004
  * Decoder fixes: Fix thaw ordering for frozen objects. Nested THAW
    operations now happen in the documented LIFO order. Thanks to Marco
    Fontani for the report.
* Thu Feb  9 2023 Tina Müller <timueller+perl@suse.de>
- updated to 5.003
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  5.003
  * Production release of 5.002_001 and 5.002_002
  * OpenBSD build fixes. Gracious thanks to Andrew Hewus Fresh
    for providing guidance and access to an OpenBSD box to use to
    debug and fix this.
  * Update Miniz to 3.0.2, Zstd to 1.5.2 and Devel::CheckLib to 1.16
  * Assorted build fixes related to these updates.
  5.002_002
  * OpenBSD build fixes. Gracious thanks to Andrew Hewus Fresh
    for providing guidance and access to an OpenBSD box to use to
    debug and fix this.
  5.002_001
  * Update Miniz to 3.0.2, Zstd to 1.5.2 and Devel::CheckLib to 1.16
  * Assorted build fixes related to these updates.
  5.002
  * Fixup Decoder tests to run on perl 5.8 which has no defined-or.
  - Consolidated changes from 5.001_00x:
  * Ensure that Encoder depends on the correct version of the Decoder.
    Gracious thanks to Slaven Rezic for being so patient in helping
    me get this release working properly.
  * Test compatibility fixes when no perl is already installed.
  * Add t/195_backcompat.t to check if the latest decoder will
    seamlessly handle reading output from older versions.
  * Test compatibility fixes with version 3 and earlier.
  5.001_003
  * Ensure that Encoder depends on the correct version of the Decoder.
    Gracious thanks to Slaven Rezic for being so patient in helping
    me get 5.001_00x working properly.
  5.001_002
  * Test compatibility fixes when no perl is already installed.
  * Decoder: Add t/195_backcompat.t to check if the latest decoder
    will seamlessly handle reading output from older versions.
  5.001_001
  * Test compatibility fixes with version 3 and earlier.
* Sun Sep  4 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.001
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
* Fri Jul 29 2022 Tina Müller <timueller+perl@suse.de>
- updated to 4.025
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.025 Thr Jul 28, 2022
  * Release with build fixes for the Decoder under threaded
    perls and MANIFEST update.
  4.024 Wed Jul 27, 2022
  * Changes to the FREEZE/THAW mechanism. Remove the part that
    says that FREEZE cannot return a list. It can, and we have
    supported it for a very long time, although I have not checked
    how far back this support goes. If you use the FREEZE/THAW
    API's you should upgrade to this version.
  * Test fixes for t/020_sort_keys.t hanging on some perls
    which do not come bundled with Hash::Util.
* Mon Feb 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 4.023
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.023 Sun Feb 20, 2022
  * Make it possible to upgrade with passing tests when using
    Sereal::Decoder 4.015 - 4.019 on threaded debugging perls.
    IF YOU USE THREADED PERLS YOU ARE STRONGLY ADVISED TO UPDATE
    TO THIS VERSION OR LATER. *UPGRADE THE DECODER IMMEDIATELY.*
  4.022 Sat Feb 19, 2022
  4.021 Fri Feb 18, 2022
  * Early but incomplete versions of 4.023, skip these releases.
  4.020 Thurs Feb 17, 2022
  * Fix "panic: free from wrong pool" errors on threaded debugging builds.
    This error is only visible on DEBUGGING perls however it exists
    regardless. If you are using a threaded build upgrade to this!
    Thanks to Andreas J. Koenig for finding the bug, and Nicholas Clark
    for suggesting valgrind to debug and fix it.
* Tue Feb  8 2022 Tina Müller <timueller+perl@suse.de>
- updated to 4.019
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.019 Mon Feb 7, 2022
  * Fix build issue with latest perl - Thanks to Nicholas Clark
  * Update zstd to 1.5.1
* Tue Aug  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.018
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.018 Thurs Aug 3, 2020
  * Fix issue with gcc 10 with snappy compression.
* Fri Jul 10 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.017
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.017 Thurs July 9, 2020
  * The build fixes in 4.016 didn't work correctly, this should fix them.
  4.016 Thurs July 9, 2020
  * Fix some dependency issues in build process
  4.015 Weds  July 8, 2020
  * Build fixes (missing dependency)
* Fri Jun 12 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.014
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.014 Thurs June 11, 2020
  * Fix build issue on non-win32 platforms.
  * Update zstd to 1.4.5
  4.012 Weds June 10, 2020
  * Fix memory leak in looks_like_sereal(), thanks to Kirill Sysoev
* Wed Feb  5 2020 <timueller+perl@suse.de>
- updated to 4.011
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.011 Tues February 4, 2020
  * Fix and test custom opcode logic for 5.31.2 and later.
  4.010 Tues February 4, 2020
  * Update miniz
  * Update zstd
  * perltidy perl code to a standard style
* Sat Feb  1 2020 <timueller+perl@suse.de>
- updated to 4.009
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.009 Fri January 31, 2020
  * Update ppport.h for modern perls.
  4.008 Thurs January 30, 2020
  * Fixup casting error for pedantic compilers in srl_compress.h
  * Build fixes.
* Fri Aug 30 2019 Tina Mueller <tina.mueller@suse.com>
- Add custom_build in cpanspec.yml. make doesn't work here with -j...
* Wed Apr 10 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.007
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.007 Tues Apr 9, 2019
  * Version bump only
  4.006 Mon Apr 8, 2019
  * Version bump only
* Tue Apr  9 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.006
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
* Mon Oct 22 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of summary.
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 4.005
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
* Fri Sep  2 2016 coolo@suse.com
- updated to 3.015
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.015 Thu Sep  1 20:18:44 CEST 2016
  * Fix builds under 5.25+
* Wed Dec  9 2015 coolo@suse.com
- updated to 3.014
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.014 Dec  7 2015
  * Fix builds under 5.8.9
  3.012 Dec  6 2015
  * Yet another release related to broken META files.
    ExtUtils::MakeMaker and CPAN::Meta need to be up to date
    or the META files miss stuff.
  3.011 Dec  6 2015
  * No significant changes. Doc typo fixes, and build tweaks.
  3.010 Dec  1 2015
  * Build fixes.
* Wed Dec  2 2015 coolo@suse.com
- updated to 3.009
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.009 Nov 30 2015
  * Re-relase 3.008 with updated META files.
* Sat Nov 28 2015 coolo@suse.com
- updated to 3.008
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.008 Nov 27 2015
  * FIX: Make sure that reserializing a data structure created
    using alias_varint_under does not produce a corrupted dataset.
    Thanks to Iskra for the report.
  * FIX: Precedence issue related to sort keys options. Thanks
    to Petr Písař <ppisar@redhat.com> for the report and fix.
  * FIX: Win32 build issues, thanks to bulk88 for help.
  3.007 Nov 26 2015
  * FIX: sorting should now work with tied hashes, and
    be in general faster.
  * CHANGED: Sort order for sort_keys=1 is now defined to be
    "in order by length of bytes, then by byte order of the
    underlying string, then by utd8ness, with non-utf8 first".
    This sort order was chosen because it requires the least
    operations to perform in the most cases, has a bounded number
    of cases where we would have to create any temporary SV's or
    to do operations that require us to introspect codepoints in
    utf8 strings. IOW purely performance. Note that so long
    as you compare data created with the same sort_keys setting
    you will ALWAYS get the same order *in process*, regardless
    of what you choose. Backwards compatible support for  the
    old order is available via sort_keys=3.
    ADDED: sort_keys=2 to provide "perl cmp order"
    (Its just there because it is easy to do, not for any
    good reason.)
    ADDED: sort_keys=3 to provide "rev perl cmp order"
    Legacy sort order was equivalent to sort_keys=3, use this
    option *ONLY* if you are extremely sensitive to changes in the
    sorted order (or "canonical form").
  * [DECODER] Build fixes for boxes without any Sereal installed (it seems
    to be common on certain types of smokers, and not on others).
  * Fix issues with serializing blessed scalars where we see the
    blessed scalar before we see the reference to it.
  * Handle PVLV undefs
  * Build fixes for 5.8.9
  * Doc patches
  * Optimizations
* Sun Nov 15 2015 coolo@suse.com
- updated to 3.006
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.006 Nov 14 2015
  * [DECODER] fix segfaults from heavily corrupted data. Guards
    against various pathological cases which could cause segfaults
    fixed. Thanks to Damian Gryski and "fuzzing sereal with afl"
    for finding these cases.
  * [ENCODER] Various subtle fixes to how we choose whether to serialize
    the string or numeric version of a value, in particular to
    ensure that "00" always round trips as "00", and related issues.
    Note this fix has correctness and performance consequences. In
    some cases values that used to serialized as integers (arguably
    incorrectly) will be serialized as strings instead, and some code
    maybe be slower to serialize.
    NOTE: Some issues related to this subject are not fixable without
    a protocol change. In particular this change may affect the behavior
    of code that uses binary logical operators on values serialized
    with Perl.
    Thanks to Zefram, Tom, and others for help with this issue.
  * Fixups for cast warnings under -Wint-to-ptr builds by using
    using PTR2INT and INT2PTR for casting our objects.
  * Win32 fixes
  * Build improvements
  * Changes to how we generate constants
* Tue Apr 14 2015 coolo@suse.com
- updated to 3.005
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
* Fri Oct  4 2013 coolo@suse.com
- initial package 0.37
  * created by cpanspec 1.78.07
